@@ -190,16 +190,14 @@
 # Sets the vcov, vcov_type, and cluster components when given a user-supplied vcov;
 # for use in summary.glm_weightit()
 .set_vcov <- function(object, vcov, vcov_type = NULL) {
-  object$vcov <- vcov
-
   object$vcov_type <- {
     if (is_null(vcov)) "none"
-    else if_null_then(vcov_type, .attr(vcov, "vcov_type"))
+    else vcov_type %or% .attr(vcov, "vcov_type")
   }
 
   attr(object, "cluster") <- .attr(vcov, "cluster")
 
-  object$vcov <- .modify_vcov_info(object[["vcov"]])
+  object$vcov <- .modify_vcov_info(vcov)
 
   object
 }
@@ -243,7 +241,8 @@
 
   internal_model_call <- .build_internal_model_call(object, vcov = vcov.)
 
-  .compute_vcov(object, object[["weightit"]], vcov., cluster, object[["call"]], internal_model_call)
+  .compute_vcov(object, object[["weightit"]], vcov., cluster,
+                object[["call"]], internal_model_call)
 }
 
 .modify_vcov_info <- function(vcov, vcov_type = NULL, cluster = NULL) {
@@ -587,12 +586,14 @@
   }
 
   if (is_not_null(cluster) && vcov %in% c("none", "const")) {
-    .wrn("`cluster` is not used when `vcov = %s`", add_quotes(vcov))
+    .wrn(sprintf("`cluster` is not used when `vcov = %s`",
+                 add_quotes(vcov)))
   }
 
   if (vcov == "none") {
-    return(.modify_vcov_info(matrix(nrow = 0L, ncol = 0L),
-                             vcov_type = "none", cluster = cluster))
+    return(.modify_vcov_info(sq_matrix(n = 0L),
+                             vcov_type = "none",
+                             cluster = cluster))
   }
 
   bout <- fit[["coefficients"]]
@@ -614,7 +615,7 @@
       V <- .solve_hessian(-fit[["hessian"]])
     }
     else if (inherits(fit, "coxph_weightit")) {
-      V <- if_null_then(fit[["naive.var"]], fit[["var"]])
+      V <- fit[["naive.var"]] %or% fit[["var"]]
     }
     else {
       .declass <- function(obj) {
@@ -630,8 +631,8 @@
     return(.modify_vcov_info(V, vcov_type = "const", cluster = cluster))
   }
 
-  Xout <- if_null_then(fit[["x"]], model.matrix(fit))
-  Y <- if_null_then(fit[["y"]], model.response(model.frame(fit)))
+  Xout <- fit[["x"]] %or% model.matrix(fit)
+  Y <- fit[["y"]] %or% model.response(model.frame(fit))
 
   if (is_not_null(weightit)) {
     W <- weightit[["weights"]]
@@ -649,7 +650,7 @@
     SW <- rep_with(1, Y)
   }
 
-  offset <- if_null_then(fit[["offset"]], rep_with(0, Y))
+  offset <- fit[["offset"]] %or% rep_with(0, Y)
 
   if (any(aliased)) {
     if (is_not_null(.attr(fit[["qr"]][["qr"]], "aliased"))) {
@@ -658,6 +659,7 @@
     else {
       Xout <- make_full_rank(Xout, with.intercept = FALSE)
     }
+
     bout <- bout[!aliased]
   }
 
@@ -680,7 +682,7 @@
     if (p > 1L) {
       clu <- lapply(seq_len(p), function(i) utils::combn(seq_len(p), i, simplify = FALSE))
       clu <- unlist(clu, recursive = FALSE)
-      sgn <- vapply(clu, function(i) (-1)^(length(i) + 1L), numeric(1L))
+      sgn <- (-1L)^(lengths(clu) + 1L)
       paste_ <- function(...) paste(..., sep = "_")
       for (i in (p + 1L):length(clu)) {
         cluster <- cbind(cluster, Reduce(paste_, unclass(cluster[, clu[[i]]])))
@@ -711,15 +713,33 @@
     internal_model_call$model <- FALSE
 
     if (is_not_null(weightit)) {
+      if (!came_from_weightit(weightit)) {
+        .err("the supplied `weightit` object does not appear to be the result of a call to `weightit()` or `weightitMSM()`, so bootstrapping cannot be used")
+      }
+
       wcall <- weightit[["call"]]
       wenv <- weightit[["env"]]
 
-      if (deparse1(wcall[[1L]]) %nin% c("weightit", "weightitMSM")) {
-        .err("the supplied `weightit` object does not appear to be the result of a call to `weightit()` or `weightitMSM()`, so bootstrapping cannot be used")
+      if (is_not_null(.attr(weightit, "calibrate"))) {
+        .calibrate <- .attr(weightit, "calibrate")
+        boot_calibrate <- function(x) {
+          calibrate(x, method = .calibrate[["method"]])
+        }
+      }
+      else {
+        boot_calibrate <- base::identity
+      }
+
+      if (is_not_null(.attr(weightit, "trim"))) {
+        .trim <- .attr(weightit, "trim")
+        boot_trim <- function(x) {
+          trim(x, at = .trim[["at"]], lower = .trim[["lower"]],
+               drop = .trim[["drop"]])
+        }
+      }
+      else {
+        boot_trim <- base::identity
       }
-    }
-    else {
-      weightit_boot <- list(weights = 1)
     }
 
     genv <- environment(fit[["formula"]])
@@ -730,7 +750,9 @@
 
         suppressMessages({
           weightit_boot <- .eval_fit(wcall, envir = wenv,
-                                     warnings = c("some extreme weights were generated" = NA))
+                                     warnings = c("some extreme weights were generated" = NA)) |>
+            boot_calibrate() |>
+            boot_trim()
         })
 
         internal_model_call$weights <- weightit_boot[["weights"]] * SW * w
@@ -777,22 +799,43 @@
     genv <- environment(fit[["formula"]])
 
     if (is_not_null(weightit)) {
-      wcall <- weightit[["call"]]
-      wenv <- weightit[["env"]]
-
-      if (deparse1(wcall[[1L]]) %nin% c("weightit", "weightitMSM")) {
+      if (!came_from_weightit(weightit)) {
         .err("the supplied `weightit` object does not appear to be the result of a call to `weightit()` or `weightitMSM()`, so bootstrapping cannot be used")
       }
 
+      wcall <- weightit[["call"]]
+      wenv <- weightit[["env"]]
+
       data <- eval(wcall$data, wenv)
       if (is_null(data)) {
         .err(sprintf('a dataset must have been supplied to `data` in the original call to `%s()` to use `vcov = "BS"`',
                      rlang::call_name(wcall)))
       }
+
+      if (is_not_null(.attr(weightit, "calibrate"))) {
+        .calibrate <- .attr(weightit, "calibrate")
+        boot_calibrate <- function(x) {
+          calibrate(x, method = .calibrate[["method"]])
+        }
+      }
+      else {
+        boot_calibrate <- base::identity
+      }
+
+      if (is_not_null(.attr(weightit, "trim"))) {
+        .trim <- .attr(weightit, "trim")
+        boot_trim <- function(x) {
+          trim(x, at = .trim[["at"]], lower = .trim[["lower"]],
+               drop = .trim[["drop"]])
+        }
+      }
+      else {
+        boot_trim <- base::identity
+      }
     }
     else {
-      weightit_boot <- list(weights = 1)
       data <- eval(internal_model_call$data, genv)
+
       if (is_null(data)) {
         .err(sprintf('a dataset must have been supplied to `data` in the original call to `%s()` to use `vcov = "BS"`',
                      rlang::call_name(model_call)))
@@ -806,7 +849,9 @@
 
         suppressMessages({
           weightit_boot <- .eval_fit(wcall, envir = wenv,
-                                     warnings = c("some extreme weights were generated" = NA))
+                                     warnings = c("some extreme weights were generated" = NA)) |>
+            boot_calibrate() |>
+            boot_trim()
         })
 
         internal_model_call$weights <- weightit_boot$weights * SW[ind]
@@ -875,14 +920,10 @@
       fit$psi(Bout, Xout, Y, w * SW, offset = offset)
     }
 
-    psi_b <- if_null_then(fit[["gradient"]],
-                          psi_out(bout, W, Y, Xout, SW, offset))
+    psi_b <- fit[["gradient"]] %or% psi_out(bout, W, Y, Xout, SW, offset)
 
-    H <- {
-      if (is_not_null(fit[["hessian"]])) {
-        fit$hessian
-      }
-      else if (inherits(fit, "ordinal_weightit")) {
+    H <- fit[["hessian"]] %or% {
+      if (inherits(fit, "ordinal_weightit")) {
         .get_hess_ordinal(fit)
       }
       else if (inherits(fit, "multinom_weightit")) {
@@ -1049,7 +1090,7 @@
 }
 
 .get_hess_glm <- function(fit) {
-  X <- if_null_then(fit[["x"]], model.matrix(fit))
+  X <- fit[["x"]] %or% model.matrix(fit)
 
   d1mus <- fit$family$mu.eta(fit$linear.predictors)
   varmus <- fit$family$variance(fit$fitted.values)
