@@ -375,8 +375,8 @@
 }
 
 .get_hess_ordinal <- function(fit) {
-  x <- if_null_then(fit[["x"]], model.matrix(fit))
-  y <- if_null_then(fit[["y"]], model.response(model.frame(fit)))
+  x <- fit[["x"]] %or% model.matrix(fit)
+  y <- fit[["y"]] %or% model.response(model.frame(fit))
   fam <- fit[["family"]]
   weights <- weights(fit)
   offset <- fit$offset
