@@ -114,7 +114,7 @@
 #'   combination of the predictions optimize a balance criterion, which must be
 #'   set with the `criterion` argument, described below.
 #'   \describe{
-#'     \item{`criterion`}{a string describing the balance criterion used to select the best weights. See \pkgfun{cobalt}{bal.compute} for allowable options for each treatment type. For binary and multi-category treatments, the default is `"smd.mean"`, which minimizes the average absolute standard mean difference among the covariates between treatment groups. For continuous treatments, the default is `"p.mean"`, which minimizes the average absolute Pearson correlation between the treatment and covariates.
+#'     \item{`criterion`}{a string describing the balance criterion used to select the best weights. See [cobalt::bal.compute()] for allowable options for each treatment type. For binary and multi-category treatments, the default is `"smd.mean"`, which minimizes the average absolute standard mean difference among the covariates between treatment groups. For continuous treatments, the default is `"p.mean"`, which minimizes the average absolute Pearson correlation between the treatment and covariates.
 #'     }
 #'   }
 #'   Note that this implementation differs from that of Pirracchio and Carone
@@ -273,16 +273,10 @@ weightit2super <- function(covs, treat, s.weights, subset, estimand, focal,
     covs <- add_missing_indicators(covs)
   }
 
-  for (i in seq_col(covs)) {
-    covs[, i] <- .make_closer_to_1(covs[, i])
-  }
-
-  covs <- as.data.frame(covs)
-
-  if (ncol(covs) > 1L) {
-    colinear.covs.to.remove <- setdiff(colnames(covs), colnames(make_full_rank(covs)))
-    covs <- covs[, colnames(covs) %nin% colinear.covs.to.remove, drop = FALSE]
-  }
+  covs <- covs |>
+    .make_covs_closer_to_1() |>
+    .make_covs_full_rank() |>
+    as.data.frame()
 
   SL.method <- ...get("SL.method", eval(formals(SuperLearner::SuperLearner)[["method"]]))
   env <- ...get("env", environment(SuperLearner::SuperLearner))
@@ -301,8 +295,7 @@ weightit2super <- function(covs, treat, s.weights, subset, estimand, focal,
 
   if (identical(SL.method, "method.balance")) {
 
-    criterion <- if_null_then(...get("criterion"),
-                              ...get("stop.method"))
+    criterion <- ...get("criterion") %or% ...get("stop.method")
 
     if (is_null(criterion)) {
       .wrn('no `criterion` was provided. Using "smd.mean"')
@@ -346,7 +339,7 @@ weightit2super <- function(covs, treat, s.weights, subset, estimand, focal,
     #Note: do.call() is needed because arguments are quoted
     fit <- do.call(SuperLearner::SuperLearner,
                    list(Y = treat,
-                        X = as.data.frame(covs),
+                        X = covs,
                         family = binomial(),
                         SL.library = SL.library,
                         verbose = FALSE,
@@ -393,16 +386,10 @@ weightit2super.multi <- function(covs, treat, s.weights, subset, estimand, focal
     covs <- add_missing_indicators(covs)
   }
 
-  for (i in seq_col(covs)) {
-    covs[, i] <- .make_closer_to_1(covs[, i])
-  }
-
-  covs <- as.data.frame(covs)
-
-  if (ncol(covs) > 1L) {
-    colinear.covs.to.remove <- setdiff(colnames(covs), colnames(make_full_rank(covs)))
-    covs <- covs[, colnames(covs) %nin% colinear.covs.to.remove, drop = FALSE]
-  }
+  covs <- covs |>
+    .make_covs_closer_to_1() |>
+    .make_covs_full_rank() |>
+    as.data.frame()
 
   SL.method <- ...get("SL.method", eval(formals(SuperLearner::SuperLearner)[["method"]]))
   env <- ...get("env", environment(SuperLearner::SuperLearner))
@@ -429,7 +416,7 @@ weightit2super.multi <- function(covs, treat, s.weights, subset, estimand, focal
       #Note: do.call() is needed because arguments are quoted
       fit.list[[i]] <- do.call(SuperLearner::SuperLearner,
                                list(Y = treat_i,
-                                    X = as.data.frame(covs),
+                                    X = covs,
                                     family = binomial(),
                                     SL.library = SL.library,
                                     verbose = FALSE,
@@ -478,14 +465,10 @@ weightit2super.cont <- function(covs, treat, s.weights, subset, stabilize, missi
     covs <- add_missing_indicators(covs)
   }
 
-  for (i in seq_col(covs)) {
-    covs[, i] <- .make_closer_to_1(covs[, i])
-  }
-
-  if (ncol(covs) > 1L) {
-    colinear.covs.to.remove <- setdiff(colnames(covs), colnames(make_full_rank(covs)))
-    covs <- covs[, colnames(covs) %nin% colinear.covs.to.remove, drop = FALSE]
-  }
+  covs <- covs |>
+    .make_covs_closer_to_1() |>
+    .make_covs_full_rank() |>
+    as.data.frame()
 
   #Process density params
   densfun <- .get_dens_fun(use.kernel = isTRUE(...get("use.kernel")), bw = ...get("bw"),
@@ -510,8 +493,7 @@ weightit2super.cont <- function(covs, treat, s.weights, subset, stabilize, missi
 
   if (identical(SL.method, "method.balance")) {
 
-    criterion <- if_null_then(...get("criterion"),
-                              ...get("stop.method"))
+    criterion <- ...get("criterion") %or% ...get("stop.method")
 
     if (is_null(criterion)) {
       .wrn('no `criterion` was provided. Using "p.mean"')
@@ -544,7 +526,7 @@ weightit2super.cont <- function(covs, treat, s.weights, subset, stabilize, missi
     #Note: do.call() is needed because arguments are quoted
     fit <- do.call(SuperLearner::SuperLearner,
                    list(Y = treat,
-                        X = as.data.frame(covs),
+                        X = covs,
                         family = gaussian(),
                         SL.library = SL.library,
                         verbose = FALSE,
