@@ -565,21 +565,36 @@ print.weightitMSM <- function(x, ...) {
     }
   }
 
-  trim <- .attr(x[["weights"]], "trim")
-  if (is_not_null(trim)) {
-    if (trim < 1) {
-      if (.attr(x[["weights"]], "trim.lower")) {
-        trim <- c(1 - trim, trim)
+  #trim
+  if (is_not_null(.attr(x, "trim"))) {
+    trim.at <- .attr(x, "trim")[["at"]]
+    trim.lower <- .attr(x, "trim")[["lower"]]
+    trim.drop <- .attr(x, "trim")[["drop"]]
+  }
+  else if (is_not_null(.attr(x[["weights"]], "trim"))) {
+    trim.at <- .attr(x[["weights"]], "trim")
+    trim.lower <- .attr(x[["weights"]], "trim.lower")
+    trim.drop <- FALSE
+  }
+  else {
+    trim.at <- NULL
+  }
+
+  if (is_not_null(trim.at) && chk::vld_number(trim.at)) {
+    if (trim.at < 1) {
+      if (trim.lower) {
+        trim.at <- c(1 - trim.at, trim.at)
       }
 
-      cat(sprintf(" - weights trimmed at %s\n",
-                  word_list(paste0(round(100 * trim, 2L), "%"))))
+      cat(sprintf(" - weights trimmed at %s%s\n",
+                  word_list(paste0(round(100 * trim.at, 2L), "%")),
+                  if (trim.drop) " and units dropped" else ""))
     }
     else {
-      cat(sprintf(" - weights trimmed at the %s %s\n",
-                  if (.attr(x[["weights"]], "trim.lower")) "top and bottom"
-                  else "top",
-                  trim))
+      cat(sprintf(" - weights trimmed at the %s %s%s\n",
+                  if (trim.lower) "top and bottom" else "top",
+                  trim.at,
+                  if (trim.drop) " and units dropped" else ""))
     }
   }
 
